componenttools.split_components_cyclically_by_prolated_durations_and_do_not_fracture_crossing_spanners
======================================================================================================

.. autofunction:: abjad.tools.componenttools.split_components_cyclically_by_prolated_durations_and_do_not_fracture_crossing_spanners
